@@ -23,4 +23,10 @@ def hash_object(obj, base=64):
 	elif base == 32:
 		return base32hex.b32encode(hash_maker.digest()).replace('=', '-')
 	else:
-		raise ValueError(f'base{base} is unknown!')
\ No newline at end of file
+		raise ValueError(f'base{base} is unknown!')
+
+
+smart_hash = hash_object
+
+
+hash = hash_object
