@@ -133,7 +133,10 @@ def make_dataframe_hashable(data):
 		aggregate_dictionary = spark_aggregate.first().asDict()
 
 	elif use == 'pandas':
-		pandas_int_data = pandas_compressed.applymap(_hash_int, na_action=None)
+		try:
+			pandas_int_data = pandas_compressed.applymap(_hash_int, na_action=None)
+		except TypeError:
+			pandas_int_data = pandas_compressed.apply(lambda x: x.map(_hash_int, na_action=None))
 
 		def pandas_bitwise_xor(numbers):
 			return reduce(lambda x, y: np.bitwise_xor(x, y), numbers)
